@@ -86,7 +86,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
@@ -217,7 +217,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -227,7 +227,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
